<?php
session_start();
// Database connection
include '../connection.php';

// Check if admin is logged in
if ($_SESSION["admin"] != true) {
    header("location:login.php");
    exit;
}

$message = ""; // Variable to hold the message

// Handle form submission and file upload
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['submit_tender'])) {
    $tender_title = mysqli_real_escape_string($conn, $_POST['tender_title']);
    $tender_date = mysqli_real_escape_string($conn, $_POST['tender_date']);
    $tender_place = mysqli_real_escape_string($conn, $_POST['tender_place']);
    $tender_details = mysqli_real_escape_string($conn, $_POST['tender_details']);

    // Check if the tender with the same title and date already exists
    $check_sql = "SELECT * FROM tenders WHERE tender_title = ? AND tender_date = ?";
    $stmt = $conn->prepare($check_sql);
    $stmt->bind_param("ss", $tender_title, $tender_date);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        // Tender already exists
        $message = "<p style='color:red;'>A tender with this title and date already exists. Please try again with different details.</p>";
    } else {
        // File handling
        $target_dir = "../uploads/Tenders/";
        $target_file = $target_dir . basename($_FILES["file_location"]["name"]);
        $file_type = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

        // Check if the file is a PDF
        if ($file_type != "pdf") {
            $message = "<p style='color:red;'>Sorry, only PDF files are allowed.</p>";
        } else {
            // Check file size (e.g., limit to 10MB)
            if ($_FILES["file_location"]["size"] > 10000000) {
                $message = "<p style='color:red;'>Sorry, your file is too large. Max file size is 10MB.</p>";
            } else {
                // Move the uploaded file
                if (move_uploaded_file($_FILES["file_location"]["tmp_name"], $target_file)) {
                    // Insert tender data into the database using prepared statements
                    $insert_sql = "INSERT INTO tenders (tender_title, tender_date, tender_place, tender_details, file_location)
                                   VALUES (?, ?, ?, ?, ?)";
                    $stmt = $conn->prepare($insert_sql);
                    $stmt->bind_param("sssss", $tender_title, $tender_date, $tender_place, $tender_details, $target_file);

                    if ($stmt->execute()) {
                        $message = "<p style='color:green;'>New record created successfully.</p>";
                        header("Location: ".$_SERVER['PHP_SELF']); // Refresh the page after insertion
                        exit; // Terminate the script
                    } else {
                        $message = "<p style='color:red;'>Error: " . $stmt->error . "</p>";
                    }

                    // Close the statement after executing it
                    $stmt->close();
                } else {
                    $message = "<p style='color:red;'>Sorry, there was an error uploading your file.</p>";
                }
            }
        }
    }
}

// Handle tender deletion
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['delete_id'])) {
    $delete_id = $_POST['delete_id'];

    // Retrieve the file location first
    $select_sql = "SELECT file_location FROM tenders WHERE ID = ?";
    $stmt = $conn->prepare($select_sql);
    $stmt->bind_param("i", $delete_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $row = $result->fetch_assoc();
        $file_location = $row['file_location'];

        // Try to unlink (delete) the file
        if (file_exists($file_location)) {
            if (unlink($file_location)) {
                $message = "<p style='color:green;'>File deleted successfully.</p>";
            } else {
                $message = "<p style='color:red;'>Error deleting the file.</p>";
            }
        } else {
            $message = "<p style='color:red;'>File not found on the server.</p>";
        }

        // Now delete the tender record from the database
        $delete_sql = "DELETE FROM tenders WHERE ID = ?";
        $stmt = $conn->prepare($delete_sql);
        $stmt->bind_param("i", $delete_id);

        if ($stmt->execute()) {
            $message = "<p style='color:green;'>Tender deleted successfully.</p>";
            header("Location: ".$_SERVER['PHP_SELF']); // Refresh the page after deletion
            exit; // Terminate the script
        } else {
            $message = "<p style='color:red;'>Error: " . $stmt->error . "</p>";
        }
    } else {
        $message = "<p style='color:red;'>Tender not found.</p>";
    }

    $stmt->close();
}

// Retrieve tenders to display
$sql = "SELECT * FROM tenders";
$result = $conn->query($sql);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" type="text/css" href="style.css">
    <title>Tender Submission and Display</title>
    <script>
        // Basic client-side validation
        function validateForm() {
            let tenderTitle = document.getElementById('tender_title').value;
            let tenderDate = document.getElementById('tender_date').value;
            let tenderPlace = document.getElementById('tender_place').value;
            let tenderDetails = document.getElementById('tender_details').value;
            let fileLocation = document.getElementById('file_location').value;

            if (tenderTitle == "" || tenderDate == "" || tenderPlace == "" || tenderDetails == "" || fileLocation == "") {
                alert("All fields are required.");
                return false;
            }
            return true;
        }
    </script>
</head>
<body>

    <h2>Submit Tender</h2>
    <form action="" method="post" enctype="multipart/form-data" onsubmit="return validateForm()">
        <label for="tender_title">Tender Title:</label> 
        <input type="text" id="tender_title" name="tender_title" required><br> 

        <label for="tender_date">Tender Date:</label> 
        <input type="date" id="tender_date" name="tender_date" required><br> 

        <label for="tender_place">Tender Place:</label> 
        <input type="text" id="tender_place" name="tender_place" required><br> 

        <label for="tender_details">Tender Details:</label> 
        <textarea id="tender_details" name="tender_details" required></textarea><br> 

        <label for="file_location">Upload Tender PDF:</label> 
        <input type="file" id="file_location" name="file_location" accept=".pdf" required><br> 

        <input type="submit" name="submit_tender" value="Submit Tender">
    </form>

    <?php
    // Display the message (if any) under the form
    if ($message) {
        echo "<div class='message'>" . $message . "</div>";
    }
    ?>

    <h2>Already Inserted Tenders</h2>
    <?php
    // Display the tenders inserted into the database
    if ($result->num_rows > 0) {
        echo "<table border='1'>
                <tr>
                    <th>ID</th>
                    <th>Tender Title</th>
                    <th>Tender Date</th>
                    <th>Tender Place</th>
                    <th>Tender Details</th>
                    <th>File Location</th>
                    <th>Action</th>
                </tr>";

        while ($row = $result->fetch_assoc()) {
            echo "<tr>
                    <td>" . $row['ID'] . "</td>
                    <td>" . $row['tender_title'] . "</td>
                    <td>" . $row['tender_date'] . "</td>
                    <td>" . $row['tender_place'] . "</td>
                    <td>" . $row['tender_details'] . "</td>
                    <td><a href='" . $row['file_location'] . "' target='_blank'>View PDF</a></td>
                    <td>
                        <form method='post' action='' onsubmit='return confirm(\"Are you sure you want to delete this tender?\")'>
                            <input type='hidden' name='delete_id' value='" . $row['ID'] . "'>
                            <input type='submit' value='Delete'>
                        </form>
                    </td>
                </tr>";
        }
        echo "</table>";
    } else {
        echo "No tenders found.";
    }

    // Close connection
    $conn->close();
    ?>

</body>
</html>
